@@ -22,6 +22,7 @@ arg_number = 0
 bot_token = ""
 
 
+
 class simple_discord_bot:
     def add_command(self, command_to_add, response, react_to=None, reaction=None, delete=False, connect_to_voicechannel=False, source_to_play=None, DM=False, disconnect_from_voice_channel=False):
 
@@ -74,6 +75,12 @@ async def on_ready():
 
 @client.event
 async def on_message(message):
+
+    on_message.triggering_message = message
+
+    global triggering_message
+    triggering_message = message
+
     try:
         if command_dict["config_options"]["respond_to_other_bots"] != False:
             if message.author.bot == True:
@@ -260,4 +267,6 @@ async def on_message(message):
                 except Exception as disconnect_error:
                     print(disconnect_error)
 
+
 print("Attempting to login to Discord...")
+
